@@ -315,13 +315,13 @@ sub addvalues {
 		# URL
 		elsif ($type eq 'url') {
 			#
-			# ldap bevat iets als:  labeledURI: http://www.uvt.nl/webwijs/show.html?anr=780251
-			# beetje onzin dat dit in ldap staat, het is afgeleide info, leidt het nu tweetalig af
+			# ldap bevat iets als:  labeledURI: http://www.uvt.nl/webwijs/show?anr=780251
+			# ldapbrowser.xml<nl>http://www.tilburguniversity.edu/nl/webwijs/show/?uid=anton.sluijtman</nl>
 			#
-			if ($value =~ /webwijs/) {
-				my ($anr) = $value =~ /anr=(\d+)/;
-				my $u = $self->{fields}->{babelfish}->translate('webwijsUrl');
-				$value = "$u$anr";
+			if ($value =~ /webwijs\/show/) {
+				my ($label) = $value =~ /webwijs\/show(\?.+)/;
+				my $url = $self->{fields}->{babelfish}->translate('webwijsUrl');
+				$value = "${url}$label" if $label;
 			}
 
 			my $h = $self->{fields}->{babelfish}->translate($attr, {'title' => 1});
@@ -364,6 +364,8 @@ sub generatefilter {
 	if (@listNodes) {
 		my $overrideAttr = $listNodes[0]->getAttribute('overrideAttr');
 		if (defined $overrideAttr) {
+#			warn "overrideAttr: $overrideAttr";
+
 			$attr = $overrideAttr;
 			($overrideValue) = $self->get_value($attr);
 		}
