@@ -1,11 +1,12 @@
 use strict;
-#use warnings  FATAL=> 'all';
+use warnings  FATAL=> 'all';
 package BaseLdapsearch;
 use Carp qw(carp cluck);
 use Baseobject;
 use Exporter;
 use Data::Dumper;
 $Data::Dumper::Indent = 1;
+use warnings FATAL=> 'all';
 
 use XML::LibXML;
 #use XML::LibXML::XPathContext;
@@ -16,19 +17,18 @@ use MIME::Base64;
 
 our @ISA=('Baseobject' );
 our @EXPORT = qw (verbosity);
-my $version ='$Id: Ldapsearch.pm 43423 2015-06-08 13:52:31Z anton $ ';
+my $version ='$Id: Ldapsearch.pm 46985 2017-09-15 13:34:04Z anton $ ';
 
-our $VERSION = "1.0";
 my $SELF;
 my $hierarchy = {};
-my $LDAP;
+my $LDAP = {};
 
 sub new {
 	my $pkg = shift;
 	my $self = bless (new Baseobject(@_),$pkg);
 	$SELF=$self;
 
-	$self->needs( [ qw (serverinfo cfhash) ] ) ;
+	$self->needs( [ qw (cfhash serverinfo) ] ) ;
 	
 	$self->allows ( { capath =>'/etc/ssl/certs' });
 	$self->allows ( [ qw ( binddn bindpwd)]);
@@ -36,6 +36,8 @@ sub new {
 	$self->fields(@_);
 	$self->checkneeds();
 
+#	$self->{fields}->{cfhash}->{serverinfo} = $self->{fields}->{serverinfo}; 
+	
 	$self->ldapinit() unless $self->error();
 	return $self;
 }
@@ -53,7 +55,7 @@ sub ldapsearch {
 		($self->{fields}->{cfhash}->{dumpldap}) ;
 
 	my $msg = $self->{ldap}->search(base   => $self->{base},
-									attrs => ['*', 'createTimestamp', 'modifyTimestamp'],
+									attrs => ['*', 'createTimestamp', 'modifyTimestamp', 'entryUUID'],
 									filter => $filter);
 
 	warn $self->inspect($msg) if $self->{fields}->{cfhash}->{dumpldap};
@@ -61,14 +63,12 @@ sub ldapsearch {
 	if ($msg->code) {
 		if ($msg->error() =~ /sizelimit exceeded/i) {
 			$self->error('sizelimitexceeded');
-		} elsif ($msg->error() =~ /Bad filter/i) {
-			warn "badfilter";
-			$self->error('badfilter');
 		} else {
-			$self->stderror("ldapsearch failed: ",$msg->error(),
+			warn ("ldapsearch failed: ", $msg->error(),
 							"\nfilter => $filter\n",
 							"base  => $self->{base}",
 				);
+			$self->friendlyerror('Search failed: '. $msg->error(). "\n");
 		}
 	}
 
@@ -91,8 +91,8 @@ sub ldapinit {
 	warn ("type: $type, port: $port, base: $base, host: $host") if $self->{fields}->{cfhash}->{dumpldap};
 	$self->{base} = $base;
 
-	unless (defined ($LDAP)) {
-		warn "CREATING NEW LDAP INSTANCE" if $self->{fields}->{cfhash}->{dumpldap};
+	unless (exists $LDAP->{$host}) {
+		warn "Creating new ldap instance for host: $host"  if $self->{fields}->{cfhash}->{dumpldap};
 		if ($type eq 'ldaps') {
 			$self->{ldap}=Net::LDAPS->new(
 				$host,
@@ -113,10 +113,10 @@ sub ldapinit {
 			warn "Invalid url in serverinfo: \"$type\", should be ldaps:// or ldap://";
 			$self->error('invalid_serverinfo');
 		}
-		$LDAP = $self->{ldap};
+		$LDAP->{$host} = $self->{ldap};
 	} else {
-		warn "NO NEW LDAPINSTANCE" if $self->{fields}->{cfhash}->{dumpldap};
-		$self->{ldap}=$LDAP;
+		warn "No new ldapinstance for host: $host" if $self->{fields}->{cfhash}->{dumpldap};
+		$self->{ldap}=$LDAP -> {$host};
 	}
 
 	unless ($self->{ldap}) {
@@ -136,7 +136,7 @@ sub ldapinit {
 			warn "error binding $self->{fields}->{binddn} on ldapserver: $type://$host", $msg->error();
 			$self->error($msg->error());
 		} else {
-			warn "BIND SUCCESSFUL FOR $self->{fields}->{binddn}" if $self->{fields}->{cfhash}->{dumpldap};
+			warn "BIND SUCCESSFUL FOR $self->{fields}->{binddn}, ldapserver: $host" if $self->{fields}->{cfhash}->{dumpldap};
 		}
 	}
 }
@@ -187,7 +187,7 @@ sub new {
 
 	$self->ldapinit();
 	return $self if ($self->error());
-	my $msg = $self->ldapsearch($self->{fields}->{filter},'savestate');
+	my $msg = $self->ldapsearch($self->{fields}->{filter}, 'savestate');
 
 	# NB, the presence of a ':' in the errormessage is a signal
 	#     for how the caller conveys the message to the user!
@@ -267,9 +267,12 @@ sub translateorgname {
 	my $orgTree = $self->{fields}->{orgTree};
 	my @node;
 	my @res;
-	my $search = "//*[\@name=\"$orgname\"]";
+	my $search = "//*[name=\"$orgname\"]";
 	my $en;
 
+	return $orgname;
+
+
 	my $value = $orgname;
 	eval  {
 		(@node)=$orgTree->{doc}->findnodes("$search");
@@ -303,7 +306,7 @@ sub decodeOrgname {
 	my $orgTree = $self->{fields}->{orgTree};
 	my @node;
 
-	my $search = "//*[\@orgID=\"$orgID\"]";
+	my $search = "//*[orgID=\"$orgID\"]";
 
 	eval {
 		(@node) = $orgTree->{doc}->findnodes("$search");
@@ -313,14 +316,13 @@ sub decodeOrgname {
 	}
 	unless (@node)  {
 		warn "decodeOrgname: organisation not found: $orgID, search: $search";
-#	die $self->inspect($orgTree->{doc}->toString(2));
 		return $orgID;
 	}
 
 	die "decodeOrgname: Multiple organisations with orgID: $orgID" if @node > 1;
 	my $h;
-	$h->{name} = $node[0]->getAttribute('name');
-	$h->{depth} = $node[0]->getAttribute('depth');
+	$h->{name} = $node[0]->findvalue('name');
+	$h->{depth} = $node[0]->findvalue('depth');
 	return $h;
 }
 
@@ -490,7 +492,7 @@ sub addhierarchy {
 	# werkt echter nog niet op etch!
 	#  my $xc = new XML::LibXML::XPathContext;
 	#  $xc->registerVarLookupFunc(sub {$_[0]->{$_[1]}}, {name => $value});
-	my $search="//*[\@name=\"$value\"]";
+	my $search="//*[name=\"$value\"]";
 
 	eval {
 		#   (@node) = $xc->find('//*[@name=$search]', $orgTree->{doc});
@@ -516,8 +518,7 @@ sub addhierarchy {
 #		warn "node: " , $node->getAttribute('name');
 		unshift (@hierarchy, $parent);
 
-		while ($parent = $parent->parentNode) {
-			last unless $parent->parentNode();
+		while ($parent = $parent->parentNode and $parent = $parent->parentNode) {
 			unshift(@hierarchy, $parent);
 		}
 	}
@@ -525,11 +526,11 @@ sub addhierarchy {
 	my @hashlist = ();
 	foreach my $el (@hierarchy)	{
 		my $h;
-		my $name = $el->getAttribute('name');
+		my $name = $el->findvalue('name');
 		$h->{org} = $name;
 		$h->{display} = $name;
-		$h->{depth} = $el->getAttribute('depth');
-		push(@hashlist,$h) unless $name eq 'treeTop';
+		$h->{depth} = $el->findvalue('depth');
+		push(@hashlist,$h);
 	}
 	# Eindresultaat:
  	push (@{$hierarchy->{hierarchylist}}, \@hashlist) if @hashlist;
@@ -548,7 +549,7 @@ sub writehierarchy {
 
 	$self->output($parent, 'value','>', {
 		'hierarchy' => $name,
-				  }) ;
+				  }) if $name;
 
 	$self->output($parent,'value', $name, {
 		'href' => "?searchContext=$searchContext&ldapfilter=$ldapfilter",
